# Table of Contents

- [managing-users](<./managing-users.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Managing Users](<./Managing-Users.md>)
  - [Authentication and Authorization](<./Managing-Users/Authentication-and-Authorization.md>)
  - [Managing Users Without SSO](<./Managing-Users/Managing-Users-Without-SSO.md>)
  - [Inviting Users](<./Managing-Users/Inviting-Users.md>)
  - [Managing Roles](<./Managing-Users/Managing-Roles.md>)
  - [Deactivating Users](<./Managing-Users/Deactivating-Users.md>)
  - [Managing Users with SSO](<./Managing-Users/Managing-Users-with-SSO.md>)
  - [Was this page helpful?](<./Managing-Users/Was-this-page-helpful.md>)
